@@ -4,17 +4,20 @@
 
 from __future__ import (unicode_literals, division, absolute_import,
                         print_function)
-import re, hashlib
+import re, hashlib, random
 from functools import partial
 from threading import Lock
-from json import load as load_json_file
+from json import load as load_json_file, dumps as json_dumps
 
 from calibre import prepare_string_for_xml, as_unicode
+from calibre.customize.ui import available_input_formats
 from calibre.db.view import sanitize_sort_field_name
-from calibre.srv.ajax import get_db, search_result
+from calibre.srv.ajax import search_result
 from calibre.srv.errors import HTTPNotFound, HTTPBadRequest
 from calibre.srv.metadata import book_as_json, categories_as_json, icon_map
 from calibre.srv.routes import endpoint, json
+from calibre.srv.utils import get_library_data, get_use_roman
+from calibre.utils.config import prefs, tweaks
 from calibre.utils.icu import sort_key
 from calibre.utils.search_query_parser import ParseException
 
@@ -50,23 +53,19 @@ def get_html(name, auto_reload_port, **replacements):
 
 @endpoint('', auth_required=False)
 def index(ctx, rd):
+    default_library = ctx.library_info(rd)[1]
     return rd.generate_static_output('/', partial(
         get_html, 'content-server/index.html', getattr(rd.opts, 'auto_reload_port', 0),
-        ENTRY_POINT='book list', LOADING_MSG=prepare_string_for_xml(_('Loading library, please wait'))))
+        ENTRY_POINT='book list',
+        LOADING_MSG=prepare_string_for_xml(_('Loading library, please wait')),
+        DEFAULT_LIBRARY=json_dumps(default_library)
+    ))
 
-def get_library_data(ctx, query):
-    library_id = query.get('library_id')
-    library_map, default_library = ctx.library_map
-    if library_id not in library_map:
-        library_id = default_library
-    db = get_db(ctx, library_id)
-    return db, library_id, library_map, default_library
-
-def get_basic_query_data(ctx, query):
-    db, library_id, library_map, default_library = get_library_data(ctx, query)
+def get_basic_query_data(ctx, rd):
+    db, library_id, library_map, default_library = get_library_data(ctx, rd)
     skeys = db.field_metadata.sortable_field_keys()
     sorts, orders = [], []
-    for x in query.get('sort', '').split(','):
+    for x in rd.query.get('sort', '').split(','):
         if x:
             s, o = x.rpartition('.')[::2]
             if o and not s:
@@ -82,6 +81,7 @@ def get_basic_query_data(ctx, query):
         sorts, orders = ['timestamp'], ['desc']
     return library_id, db, sorts, orders
 
+
 DEFAULT_NUMBER_OF_BOOKS = 50
 
 @endpoint('/interface-data/init', postprocess=json)
@@ -92,8 +92,16 @@ def interface_data(ctx, rd):
     Optional: ?num=50&sort=timestamp.desc&library_id=<default library>
               &search=''&extra_books=''
     '''
-    ans = {'username':rd.username}
-    ans['library_map'], ans['default_library'] = ctx.library_map
+    ans = {
+        'username':rd.username,
+        'output_format':prefs['output_format'].upper(),
+        'input_formats':{x.upper():True for x in available_input_formats()},
+        'gui_pubdate_display_format':tweaks['gui_pubdate_display_format'],
+        'gui_timestamp_display_format':tweaks['gui_timestamp_display_format'],
+        'gui_last_modified_display_format':tweaks['gui_last_modified_display_format'],
+        'use_roman_numerals_for_series_number': get_use_roman(),
+    }
+    ans['library_map'], ans['default_library'] = ctx.library_info(rd)
     ud = {}
     if rd.username:
         # Override session data with stored values for the authenticated user,
@@ -105,7 +113,7 @@ def interface_data(ctx, rd):
         usort = ud.get('sort')
         if usort:
             rd.query.set('sort', usort)
-    ans['library_id'], db, sorts, orders = get_basic_query_data(ctx, rd.query)
+    ans['library_id'], db, sorts, orders = get_basic_query_data(ctx, rd)
     ans['user_session_data'] = ud
     try:
         num = int(rd.query.get('num', DEFAULT_NUMBER_OF_BOOKS))
@@ -146,7 +154,7 @@ def more_books(ctx, rd):
 
     Optional: ?num=50&library_id=<default library>
     '''
-    db, library_id = get_library_data(ctx, rd.query)[:2]
+    db, library_id = get_library_data(ctx, rd)[:2]
 
     try:
         num = int(rd.query.get('num', DEFAULT_NUMBER_OF_BOOKS))
@@ -194,13 +202,13 @@ def get_books(ctx, rd):
 
     Optional: ?library_id=<default library>&num=50&sort=timestamp.desc&search=''
     '''
-    library_id, db, sorts, orders = get_basic_query_data(ctx, rd.query)
+    library_id, db, sorts, orders = get_basic_query_data(ctx, rd)
     try:
         num = int(rd.query.get('num', DEFAULT_NUMBER_OF_BOOKS))
     except Exception:
         raise HTTPNotFound('Invalid number of books: %r' % rd.query.get('num'))
     searchq = rd.query.get('search', '')
-    db = get_library_data(ctx, rd.query)[0]
+    db = get_library_data(ctx, rd)[0]
     ans = {}
     mdata = ans['metadata'] = {}
     with db.safe_read_lock:
@@ -216,6 +224,28 @@ def get_books(ctx, rd):
                 mdata[book_id] = data
     return ans
 
+@endpoint('/interface-data/book-metadata/{book_id=0}', postprocess=json)
+def book_metadata(ctx, rd, book_id):
+    '''
+    Get metadata for the specified book. If no book_id is specified, return metadata for a random book.
+
+    Optional: ?library_id=<default library>
+    '''
+    library_id, db = get_basic_query_data(ctx, rd)[:2]
+    book_ids = ctx.allowed_book_ids(rd, db)
+    def notfound():
+        raise HTTPNotFound(_('No book with id: %d in library') % book_id)
+    if not book_ids:
+        notfound()
+    if not book_id:
+        book_id = random.choice(tuple(book_ids))
+    elif book_id not in book_ids:
+        notfound()
+    data = book_as_json(db, book_id)
+    if data is None:
+        notfound()
+    return data
+
 @endpoint('/interface-data/tag-browser')
 def tag_browser(ctx, rd):
     '''
@@ -223,10 +253,10 @@ def tag_browser(ctx, rd):
     Optional: ?library_id=<default library>&sort_tags_by=name&partition_method=first letter
               &collapse_at=25&dont_collapse=&hide_empty_categories=
     '''
-    db, library_id = get_library_data(ctx, rd.query)[:2]
+    db, library_id = get_library_data(ctx, rd)[:2]
     etag = '%s||%s||%s' % (db.last_modified(), rd.username, library_id)
     etag = hashlib.sha1(etag.encode('utf-8')).hexdigest()
     def generate():
-        db, library_id = get_library_data(ctx, rd.query)[:2]
+        db, library_id = get_library_data(ctx, rd)[:2]
         return json(ctx, rd, tag_browser, categories_as_json(ctx, rd, db))
     return rd.etagged_dynamic_response(etag, generate)
